==> 0.5.0.tar.gz: test/services/meta_test.dart <==
import 'dart:html';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [Meta] class.
void main() => group('Meta', () {
  group('.charset', () {
    var meta = new Meta(document);

    test('should be a `null` reference if the document does not specify a charset', () {
      expect(querySelector('meta[charset]'), isNull);
      expect(meta.charset, isNull);
    });

    test('should return the value of the `charset` metadata if the document specifies a charset', () {
      document.head.append(new Element.tag('meta')..attributes['charset'] = 'iso-8859-15');
      expect(querySelector('meta[charset]'), isNotNull);
      expect(meta.charset, equals('ISO-8859-15'));
    });
  });

  group('.description', () {
    var meta = new Meta(document);

    test('should be a `null` reference if the document does not specify a description', () {
      expect(querySelector('meta[name="description"]'), isNull);
      expect(meta.description, isNull);
    });

    test('should return the value of the `description` metadata if the document specifies a description', () {
      document.head.append(new MetaElement()
        ..name = 'description'
        ..content = 'foo bar baz'
      );

      expect(querySelector('meta[name="description"]'), isNotNull);
      expect(meta.description, equals('foo bar baz'));
    });
  });

  group('.keywords', () {
    var meta = new Meta(document);

    test('should be an empty list if the document does not specify any keyword', () {
      expect(querySelector('meta[name="keywords"]'), isNull);
      expect(meta.keywords, isEmpty);
    });

    test('should return the parsed list fom the `keywords` metadata if the document specifies some keywords', () {
      document.head.append(new MetaElement()
        ..name = 'keywords'
        ..content = 'foo, bar, baz'
      );

      expect(querySelector('meta[name="keywords"]'), isNotNull);
      expect(meta.keywords, orderedEquals(const <String>['foo', 'bar', 'baz']));
    });
  });

  group('.themeColor', () {
    var meta = new Meta(document);

    test('should be a `null` reference if the document does not specify a theme color', () {
      expect(querySelector('meta[name="theme-color"]'), isNull);
      expect(meta.themeColor, isNull);
    });

    test('should return the value of the `theme-color` metadata if the document specifies a theme color', () {
      document.head.append(new MetaElement()
        ..name = 'theme-color'
        ..content = '#336699'
      );

      expect(querySelector('meta[name="theme-color"]'), isNotNull);
      expect(meta.themeColor, equals('#336699'));
    });
  });

  group('operator []', () {
    var meta = new Meta(document);

    test('should return a `null` reference if the meta does not exist', () {
      expect(querySelector('meta[name="operator-get"]'), isNull);
      expect(meta['operator-get'], isNull);
    });

    test('should return the value of the `content` attribute if the meta exists', () {
      document.head.append(new MetaElement()
        ..name = 'operator-get'
        ..content = 'foo'
      );

      expect(querySelector('meta[name="operator-get"]'), isNotNull);
      expect(meta['operator-get'], equals('foo'));
    });
  });

  group('operator []=', () {
    var meta = new Meta(document);

    test('should append a new meta if it does not already exist', () {
      expect(querySelector('meta[name="operator-set"]'), isNull);
      meta['operator-set'] = 'foo';

      MetaElement element = querySelector('meta[name="operator-set"]');
      expect(element.content, equals('foo'));
    });

    test('should replace the existing meta if it already exists', () {
      expect(querySelector('meta[name="operator-set"]'), isNotNull);
      meta['operator-set'] = 'bar';

      MetaElement element = querySelector('meta[name="operator-set"]');
      expect(element.content, equals('bar'));
    });
  });

  group('.getHttpEquiv()', () {
    var meta = new Meta(document);

    test('should return a `null` reference if the meta does not exist', () {
      expect(querySelector('meta[http-equiv="content-type"]'), isNull);
      expect(meta.getHttpEquiv('content-type'), isNull);
    });

    test('should return the value of the `content` attribute if the meta exists', () {
      document.head.append(new MetaElement()
        ..httpEquiv = 'content-type'
        ..content = 'text/html; charset=UTF-8'
      );

      expect(querySelector('meta[http-equiv="content-type"]'), isNotNull);
      expect(meta.getHttpEquiv('content-type'), equals('text/html; charset=UTF-8'));
    });
  });
});

==> 0.8.0.tar.gz: test/services/meta_test.dart <==
import 'dart:html';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [Meta] class.
void main() => group('Meta', () {
  group('.charset', () {
    var meta = Meta(document);

    test('should be a `null` reference if the document does not specify a charset', () {
      expect(querySelector('meta[charset]'), isNull);
      expect(meta.charset, isNull);
    });

    test('should return the value of the `charset` metadata if the document specifies a charset', () {
      document.head.append(Element.tag('meta')..attributes['charset'] = 'iso-8859-15');
      expect(querySelector('meta[charset]'), isNotNull);
      expect(meta.charset, equals('ISO-8859-15'));
    });
  });

  group('.description', () {
    var meta = Meta(document);

    test('should be a `null` reference if the document does not specify a description', () {
      expect(querySelector('meta[name="description"]'), isNull);
      expect(meta.description, isNull);
    });

    test('should return the value of the `description` metadata if the document specifies a description', () {
      document.head.append(MetaElement()
        ..name = 'description'
        ..content = 'foo bar baz'
      );

      expect(querySelector('meta[name="description"]'), isNotNull);
      expect(meta.description, equals('foo bar baz'));
    });
  });

  group('.keywords', () {
    var meta = Meta(document);

    test('should be an empty list if the document does not specify any keyword', () {
      expect(querySelector('meta[name="keywords"]'), isNull);
      expect(meta.keywords, isEmpty);
    });

    test('should return the parsed list fom the `keywords` metadata if the document specifies some keywords', () {
      document.head.append(MetaElement()
        ..name = 'keywords'
        ..content = 'foo, bar, baz'
      );

      expect(querySelector('meta[name="keywords"]'), isNotNull);
      expect(meta.keywords, orderedEquals(<String>['foo', 'bar', 'baz']));
    });
  });

  group('.themeColor', () {
    var meta = Meta(document);

    test('should be a `null` reference if the document does not specify a theme color', () {
      expect(querySelector('meta[name="theme-color"]'), isNull);
      expect(meta.themeColor, isNull);
    });

    test('should return the value of the `theme-color` metadata if the document specifies a theme color', () {
      document.head.append(MetaElement()
        ..name = 'theme-color'
        ..content = '#336699'
      );

      expect(querySelector('meta[name="theme-color"]'), isNotNull);
      expect(meta.themeColor, equals('#336699'));
    });
  });

  group('operator []', () {
    var meta = Meta(document);

    test('should return a `null` reference if the meta does not exist', () {
      expect(querySelector('meta[name="operator-get"]'), isNull);
      expect(meta['operator-get'], isNull);
    });

    test('should return the value of the `content` attribute if the meta exists', () {
      document.head.append(MetaElement()
        ..name = 'operator-get'
        ..content = 'foo'
      );

      expect(querySelector('meta[name="operator-get"]'), isNotNull);
      expect(meta['operator-get'], equals('foo'));
    });
  });

  group('operator []=', () {
    var meta = Meta(document);

    test('should append a new meta if it does not already exist', () {
      expect(querySelector('meta[name="operator-set"]'), isNull);
      meta['operator-set'] = 'foo';

      MetaElement element = querySelector('meta[name="operator-set"]');
      expect(element.content, equals('foo'));
    });

    test('should replace the existing meta if it already exists', () {
      expect(querySelector('meta[name="operator-set"]'), isNotNull);
      meta['operator-set'] = 'bar';

      MetaElement element = querySelector('meta[name="operator-set"]');
      expect(element.content, equals('bar'));
    });
  });

  group('.getHttpEquiv()', () {
    var meta = Meta(document);

    test('should return a `null` reference if the meta does not exist', () {
      expect(querySelector('meta[http-equiv="content-type"]'), isNull);
      expect(meta.getHttpEquiv('content-type'), isNull);
    });

    test('should return the value of the `content` attribute if the meta exists', () {
      document.head.append(MetaElement()
        ..httpEquiv = 'content-type'
        ..content = 'text/html; charset=UTF-8'
      );

      expect(querySelector('meta[http-equiv="content-type"]'), isNotNull);
      expect(meta.getHttpEquiv('content-type'), equals('text/html; charset=UTF-8'));
    });
  });
});
